pub struct ImportDetails {
    pub method_of_payment: Option<MethodOfPayment>,
    pub seal_number: Option<String>,
    pub route: Option<Box<Route>>,
    pub import_containers: Option<String>,
    pub billable_weight: Option<Box<Weight>>,
    pub estimated_ship_by_date: Option<String>,
}

Fields

method_of_payment: Option<MethodOfPayment>

This is used for import purchase orders only. If the recipient requests, this field will contain the shipment method of payment.

seal_number: Option<String>

The container’s seal number.

route: Option<Box<Route>>import_containers: Option<String>

Types and numbers of container(s) for import purchase orders. Can be a comma-separated list if shipment has multiple containers.

billable_weight: Option<Box<Weight>>estimated_ship_by_date: Option<String>

Date on which the shipment is expected to be shipped. This value should not be in the past and not more than 60 days out in the future.

Implementations